<?php
/**
 * The admin specific functionality of the plugin.
 *
 * @author  : Ginger Plugins <gingerplugins@gmail.com>
 * @license : GPL2
 * */
defined('ABSPATH') or die('Direct Access is not allowed');

class GP_PRO_Front_Sticky_Chat_Buttons
{

    /**
     * Check widget is active or not.
     *
     * @var    boolean    $slug    The slug of this plugin.
     * @since  1.1.2
     * @access private
     */
    private $isWidgetActive = null;

    /**
     * The settings of widget.
     *
     * @var    array    $slug    The settings of widget.
     * @since  1.1.2
     * @access private
     */
    private $settings = [];


    /**
     * Initialize the class and set its properties.
     *
     * @since 1.1.2
     */
    public function __construct()
    {

        // CSS and JavaScript files for Ginger Sticky Chat Widget.
        add_action('wp_enqueue_scripts', [ $this, 'front_end_script' ]);

    }//end __construct()


    /**
     * Enqueue front end script and css file
     *
     * @since  1.1.2
     * @return null
     */
    public function front_end_script()
    {
        $this->check_for_buttons();

        $minified = ".min";
        if (GSB_DEV_VERSION) {
            $minified = "";
        }

        if ($this->isWidgetActive) {
            wp_enqueue_script('gsb-script', GSB_PLUGIN_URL."assets/front/js/script".$minified.".js", ['jquery'], GSB_PLUGIN_VERSION);
            wp_enqueue_style('gsb-front', GSB_PLUGIN_URL."assets/front/css/front.min.css", [], GSB_PLUGIN_VERSION);

            // wp_add_inline_style( 'gsb-front', $css );
            $data = [
                'buttons' => $this->settings,
            ];
            wp_localize_script('gsb-script', "gsb_settings", $data);
        }

    }//end front_end_script()


    /**
     * Add all settings of widget.
     *
     * @since  1.1.2
     * @return boolean The widget is active or not.
     */
    public function check_for_buttons()
    {
        $args     = [
            'post_type'   => 'gsb_buttons',
            'post_status' => 'publish',
            'meta_query'  => [
                [
                    'key'     => 'widget_status',
                    'value'   => 'yes',
                    'compare' => '=',
                ],
            ],
        ];
        $posts    = get_posts($args);
        $settings = [];
        if (!empty($posts) && count($posts) > 0) {
            foreach ($posts as $post) {
                $channels = $this->check_for_channels($post->ID);
                if (!empty($channels)) {
                    $widgetSettings  = $this->get_setting($post->ID);
                    $triggerSettings = $this->get_trigger($post->ID);
                    $customCss       = $this->get_custom_css($post->ID);
                    $setting         = [
                        'channels'   => $channels,
                        'triggers'   => $triggerSettings,
                        'settings'   => $widgetSettings,
                        'custom_css' => $customCss,
                        'id'         => $post->ID,
                        'token'      => wp_create_nonce("gsb_button_settings_".$post->ID),
                        'client'     => 1,
                    ];
                    $settings[]      = $setting;
                }
            }
        }

        $this->settings       = $settings;
        $this->isWidgetActive = false;
        if (!empty($this->settings)) {
            $this->isWidgetActive = true;
        }

        return $this->isWidgetActive;

    }//end check_for_buttons()


    /**
     * Add customize widget and tooltip settings of widget.
     *
     * @since  1.1.2
     * @param  integer $postId The ID of widget.
     * @return array The setting of customize widget.
     */
    public function get_setting($postId)
    {
        $widgetSettings = get_post_meta($postId, "widget_settings", true);
        $icons          = Ginger_Social_Icons::get_chat_icons();
        $widgetSettings['icon_url'] = isset($icons[$widgetSettings['chat_icon']]) ? $icons[$widgetSettings['chat_icon']] : $icons['chat-line'];
        $widgetSettings['icon_url'] = "<div class='chat-button-icon'>".$icons[$widgetSettings['chat_icon']]['icon']."</div>";

        $tooltipSettings = get_post_meta($postId, "tooltip_settings", true);
        $widgetSettings['tooltip_settings'] = $tooltipSettings;

        // Border radius
        $borderRadius = isset($widgetSettings['border_radius']) && !empty($widgetSettings['border_radius']) ? $widgetSettings['border_radius'] : '0';
        $widgetSettings['border_radius'] = $borderRadius;

        // Tooltip font size, tooltip height, border radius
        $tooltipBorderRadius = isset($tooltipSettings['border_radius']) && !empty($tooltipSettings['border_radius']) ? $tooltipSettings['border_radius'] : '0';
        $widgetSettings['tooltip_settings']['border_radius'] = $tooltipBorderRadius;

        $tooltipFontSize = isset($tooltipSettings['font_size']) && !empty($tooltipSettings['font_size']) ? $tooltipSettings['font_size'] : '0';
        $widgetSettings['tooltip_settings']['font_size'] = $tooltipFontSize;

        $tooltipHight = isset($tooltipSettings['tooltip_height']) && !empty($tooltipSettings['tooltip_height']) ? $tooltipSettings['tooltip_height'] : '0';
        $widgetSettings['tooltip_settings']['tooltip_height'] = $tooltipHight;

        return $widgetSettings;

    }//end get_setting()


    /**
     * Get trigger settings of widget.
     *
     * @since  1.1.2
     * @param  integer $postId The ID of widget.
     * @return array The trigger settings of widget.
     */
    public function get_trigger($postId)
    {
        $triggerSettings        = get_post_meta($postId, "trigger_rules", true);
        $defaultTriggerSettings = [
            'on_scroll'     => 'no',
            'page_scroll'   => '0',
            'after_seconds' => 'no',
            'seconds'       => '0',
            'exit_intent'   => 'no',
            'browser'       => 'no',
            'on_inactivity' => 'no',
        ];
        $triggerSettings        = shortcode_atts($defaultTriggerSettings, $triggerSettings);
        if (empty($triggerSettings['seconds']) || !is_numeric($triggerSettings['seconds']) || $triggerSettings['seconds'] < 0) {
            $triggerSettings['after_seconds'] = 'no';
        }

        if (empty($triggerSettings['page_scroll']) || !is_numeric($triggerSettings['page_scroll']) || $triggerSettings['page_scroll'] < 0) {
            $triggerSettings['on_scroll'] = 'no';
        }

        if ($triggerSettings['browser'] == "no" && $triggerSettings['on_inactivity'] == "no") {
            $triggerSettings['exit_intent'] = "no";
        }

        return $triggerSettings;

    }//end get_trigger()


    /**
     * Get custom css of widget.
     *
     * @since  1.1.2
     * @param  integer $postId The ID of widget.
     * @return array The get custom css of widget.
     */
    public function get_custom_css($postId)
    {
        $customCss = get_post_meta($postId, "button_css", true);
        $css       = "";
        if (isset($customCss) && !empty($customCss)) {
            $css .= $customCss;
        }

        return $css;

    }//end get_custom_css()


    /**
     * Get all selected channel settings of widget.
     *
     * @since  1.1.2
     * @param  integer $postId The ID of widget.
     * @return array The selected channel settings of widget.
     */
    public  function check_for_channels($postId)
    {

        $isActive = get_post_meta($postId, "widget_status", true);

        $device    = "";
        $useragent = $_SERVER['HTTP_USER_AGENT'];
        if (preg_match('/(android|bb\d+|meego).+mobile|avantgo|bada\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\.(browser|link)|vodafone|wap|windows ce|xda|xiino/i', $useragent)||preg_match('/1207|6310|6590|3gso|4thp|50[1-6]i|770s|802s|a wa|abac|ac(er|oo|s\-)|ai(ko|rn)|al(av|ca|co)|amoi|an(ex|ny|yw)|aptu|ar(ch|go)|as(te|us)|attw|au(di|\-m|r |s )|avan|be(ck|ll|nq)|bi(lb|rd)|bl(ac|az)|br(e|v)w|bumb|bw\-(n|u)|c55\/|capi|ccwa|cdm\-|cell|chtm|cldc|cmd\-|co(mp|nd)|craw|da(it|ll|ng)|dbte|dc\-s|devi|dica|dmob|do(c|p)o|ds(12|\-d)|el(49|ai)|em(l2|ul)|er(ic|k0)|esl8|ez([4-7]0|os|wa|ze)|fetc|fly(\-|_)|g1 u|g560|gene|gf\-5|g\-mo|go(\.w|od)|gr(ad|un)|haie|hcit|hd\-(m|p|t)|hei\-|hi(pt|ta)|hp( i|ip)|hs\-c|ht(c(\-| |_|a|g|p|s|t)|tp)|hu(aw|tc)|i\-(20|go|ma)|i230|iac( |\-|\/)|ibro|idea|ig01|ikom|im1k|inno|ipaq|iris|ja(t|v)a|jbro|jemu|jigs|kddi|keji|kgt( |\/)|klon|kpt |kwc\-|kyo(c|k)|le(no|xi)|lg( g|\/(k|l|u)|50|54|\-[a-w])|libw|lynx|m1\-w|m3ga|m50\/|ma(te|ui|xo)|mc(01|21|ca)|m\-cr|me(rc|ri)|mi(o8|oa|ts)|mmef|mo(01|02|bi|de|do|t(\-| |o|v)|zz)|mt(50|p1|v )|mwbp|mywa|n10[0-2]|n20[2-3]|n30(0|2)|n50(0|2|5)|n7(0(0|1)|10)|ne((c|m)\-|on|tf|wf|wg|wt)|nok(6|i)|nzph|o2im|op(ti|wv)|oran|owg1|p800|pan(a|d|t)|pdxg|pg(13|\-([1-8]|c))|phil|pire|pl(ay|uc)|pn\-2|po(ck|rt|se)|prox|psio|pt\-g|qa\-a|qc(07|12|21|32|60|\-[2-7]|i\-)|qtek|r380|r600|raks|rim9|ro(ve|zo)|s55\/|sa(ge|ma|mm|ms|ny|va)|sc(01|h\-|oo|p\-)|sdk\/|se(c(\-|0|1)|47|mc|nd|ri)|sgh\-|shar|sie(\-|m)|sk\-0|sl(45|id)|sm(al|ar|b3|it|t5)|so(ft|ny)|sp(01|h\-|v\-|v )|sy(01|mb)|t2(18|50)|t6(00|10|18)|ta(gt|lk)|tcl\-|tdg\-|tel(i|m)|tim\-|t\-mo|to(pl|sh)|ts(70|m\-|m3|m5)|tx\-9|up(\.b|g1|si)|utst|v400|v750|veri|vi(rg|te)|vk(40|5[0-3]|\-v)|vm40|voda|vulc|vx(52|53|60|61|70|80|81|83|85|98)|w3c(\-| )|webc|whit|wi(g |nc|nw)|wmlb|wonu|x700|yas\-|your|zeto|zte\-/i', substr($useragent, 0, 4))) {
            $device = "mobile";
        } else {
            $device = "desktop";
        }

        if ($isActive == "yes") {
            $this->isWidgetActive = true;

            $channelsSetting = get_post_meta($postId, "channel_settings", true);

            $settings = [];
            if (!empty($channelsSetting)) {
                $socialIcons = Ginger_Social_Icons::icon_list();

                foreach ($channelsSetting as $key => $channel) {
                    if (isset($socialIcons[$key]) && ($channel['for_desktop'] || $channel['for_mobile']) && !empty($channel['value'])) {
                        $channels = $socialIcons[$key];

                        $defaultChannelSettings = [
                            'title'            => $channels['title'],
                            'bg_color'         => $channels['color'],
                            'text_color'       => '#ffffff',
                            'bg_hover_color'   => $channels['color'],
                            'text_hover_color' => '#ffffff',
                            'icon'             => $channels['icon'],
                            'for_desktop'      => 'yes',
                            'for_mobile'       => 'yes',
                            'value'            => '',
                            'custom_id'        => '',
                            'custom_class'     => '',
                            'image_id'         => '',
                            'whatsapp_message' => '',
                            'email_subject'    => '',
                        ];
                        $channelsSetting        = shortcode_atts($defaultChannelSettings, $channel);
                        $imageUrl = "";
                        $value    = trim($channelsSetting['value']);
                        if (!empty($channelsSetting['image_id'])) {
                            $imageData = wp_get_attachment_image_src($channelsSetting['image_id'], "full");
                            if (!empty($imageData) && isset($imageData[0])) {
                                $imageUrl = $imageData[0];
                            }
                        }

                        if (!empty($value)) {
                            $href   = "javascript:;";
                            $target = "";
                            if ($key == "whatsapp") {
                                $value = trim($value, "+");
                                $value = str_replace([" ","-","_"],["","",""],$value);
                                $href   = esc_url("https://web.whatsapp.com/send?phone=".$value);
                                $target = "_blank";
                                $whatsapp_message = isset($channelsSetting['whatsapp_message']) && !empty($channelsSetting['whatsapp_message']) ? $channelsSetting['whatsapp_message'] : "";
                                if (!empty($whatsapp_message)) {
                                    $href  = $href."&text=".esc_attr(trim($whatsapp_message));
                                    $value = $value."?text=".esc_attr(trim($whatsapp_message));
                                }
                            } else if ($key == "facebook_messenger") {
                                $href   = esc_url("https://m.me/".$value);
                                $target = "_blank";
                            } else if ($key == "viber") {
                                $value = trim($value, "+");
                                if ($device == "mobile") {
                                    $href = $value;
                                } else {
                                    $href = "+".$value;
                                }
                                $target = "";
                                $href   = "viber://chat?number=".$href;
                            } else if ($key == "line") {
                                $href   = esc_url($value);
                                $target = "_blank";
                            } else if ($key == "phone") {
                                $href   = "tel:".$value;
                                $target = "";
                            } else if ($key == "mail") {
                                $href   = "mailto:".trim($value);
                                $others = isset($channelsSetting['email_subject']) && !empty($channelsSetting['email_subject']) ? $channelsSetting['email_subject'] : "";
                                if (!empty($others)) {
                                    $href = $href."?subject=".esc_attr($others);
                                }
                            } else if ($key == "telegram") {
                                $href   = esc_url("https://telegram.me/".$value);
                                $target = "_blank";
                            } else if ($key == "vkontakte") {
                                $href   = esc_url("https://vk.me/".$value);
                                $target = "_blank";
                            } else if ($key == "sms") {
                                $href = "sms:".$value;
                            } else if ($key == "wechat") {
                                $channelsSetting['title'] = $channelsSetting['title'] . ": " . $channelsSetting['value'];
                            } else if ($key == "skype") {
                                $href = "skype:".$value."?chat";
                            } else if ($key == "snapchat") {
                                $href   = esc_url("https://www.snapchat.com/add/".$value);
                                $target = "_blank";
                            } else if ($key == "linkedin") {
                                $href   = esc_url("https://www.linkedin.com/".$value);
                                $target = "_blank";
                            } else if ($key == "twitter") {
                                $href   = esc_url("https://twitter.com/".$value);
                                $target = "_blank";
                            } else if ($key == "instagram") {
                                $href   = esc_url("https://www.instagram.com/".$value);
                                $target = "_blank";
                            } else if ($key == "waze") {
                                $href   = esc_url($value);
                                $target = "_blank";
                            } else if ($key == "link") {
                                $href   = esc_url($value);
                                $target = "_blank";
                            } else if ($key == "slack") {
                                $href   = esc_url($value);
                                $target = "_blank";
                            } else if ($key == "google-map") {
                                $href   = esc_url($value);
                                $target = "_blank";
                            } else if ($key == "custom-link") {
                                $href   = esc_url($value);
                                $target = "_blank";
                            } else if ($key == "signal") {
                                $value  = trim($value, "https://signal.group/");
                                $value  = trim($value, "http://signal.group/");
                                $value  = "https://signal.group/".$value;
                                $href   = esc_url($value);
                                $target = "_blank";
                            } else if ($key == "tiktok") {
                                $value  = trim($value, "https://tiktok.com/");
                                $value  = trim($value, "http://tiktok.com/");
                                $value  = trim($value, "@");
                                $value  = "https://tiktok.com/@".$value;
                                $href   = esc_url($value);
                                $target = "_blank";
                            }//end if

                            $channelSetting = [
                                'title'            => $channelsSetting['title'],
                                'bg_color'         => $channelsSetting['bg_color'],
                                'bg_hover_color'   => $channelsSetting['bg_hover_color'],
                                'text_color'       => $channelsSetting['text_color'],
                                'text_hover_color' => $channelsSetting['text_hover_color'],
                                'icon'             => $channelsSetting['icon'],
                                'href'             => $href,
                                'for_desktop'      => $channelsSetting['for_desktop'],
                                'for_mobile'       => $channelsSetting['for_mobile'],
                                'channel'          => $key,
                                'target'           => $target,
                                'image_url'        => $imageUrl,
                                'value'            => $value,
                                'custom_id'        => $channelsSetting['custom_id'],
                                'custom_class'     => $channelsSetting['custom_class'],
                            ];
                            $settings[]     = $channelSetting;
                        }//end if
                    }//end if
                }//end foreach
            }//end if

            return $settings;
        }//end if

    }//end check_for_channels()


}//end class


if (class_exists("GP_PRO_Front_Sticky_Chat_Buttons")) {
    $gpSocial = new GP_PRO_Front_Sticky_Chat_Buttons();
}
